Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJacques Lucke <jacques@blender.org>2020-06-09 11:27:24 +0300
committerJacques Lucke <jacques@blender.org>2020-06-09 11:27:24 +0300
commit9bb7d6ed68ef1aa0e6acc3e70901cb6b79c682d2 (patch)
tree843993222b8ee5c02451207404ceb113323ede6f /source/blender/blenlib/BLI_vector_set.hh
parentd8678e02ecec9375bec1dcf1388c6fc8b4ce3ad2 (diff)
BLI: put C++ data structures in "blender" namespace instead of "BLI"
We plan to use the "blender" namespace in other modules as well.
Diffstat (limited to 'source/blender/blenlib/BLI_vector_set.hh')
-rw-r--r--source/blender/blenlib/BLI_vector_set.hh14
1 files changed, 7 insertions, 7 deletions
diff --git a/source/blender/blenlib/BLI_vector_set.hh b/source/blender/blenlib/BLI_vector_set.hh
index 7e6a7de6ee6..a3155a3a9fd 100644
--- a/source/blender/blenlib/BLI_vector_set.hh
+++ b/source/blender/blenlib/BLI_vector_set.hh
@@ -20,8 +20,8 @@
/** \file
* \ingroup bli
*
* A `BLI::VectorSet<Key>` is an ordered container for elements of type `Key`. It has the same
* interface as `BLI::Set` with the following extensions:
* - The insertion order of keys is maintained as long as no elements are removed.
* - The keys are stored in a contiguous array.
*
@@ -35,9 +35,9 @@
* the keys are stored in a set. With a VectorSet, one can get an ArrayRef containing all keys
* without additional copies.
*
* BLI::VectorSet is implemented using open addressing in a slot array with a power-of-two size.
* Other than in BLI::Set, a slot does not contain the key though. Instead it only contains an
* index into an array of keys that is stored separately.
*
* Some noteworthy information:
* - Key must be a movable type.
@@ -66,7 +66,7 @@
#include "BLI_probing_strategies.hh"
#include "BLI_vector_set_slots.hh"
-namespace BLI {
+namespace blender {
template<
/**
@@ -752,6 +752,6 @@ class VectorSet {
}
};
-} // namespace BLI
+} // namespace blender
#endif /* __BLI_VECTOR_SET_HH__ */
@@ -20,8 +20,8 @@
* \ingroup bli
*
- * A `BLI::VectorSet<Key>` is an ordered container for elements of type `Key`. It has the same
- * interface as `BLI::Set` with the following extensions:
+ * A `blender::VectorSet<Key>` is an ordered container for elements of type `Key`. It has the same
+ * interface as `blender::Set` with the following extensions:
* - The insertion order of keys is maintained as long as no elements are removed.
* - The keys are stored in a contiguous array.
@@ -35,9 +35,9 @@
* without additional copies.
*
- * BLI::VectorSet is implemented using open addressing in a slot array with a power-of-two size.
- * Other than in BLI::Set, a slot does not contain the key though. Instead it only contains an
- * index into an array of keys that is stored separately.
+ * blender::VectorSet is implemented using open addressing in a slot array with a power-of-two
+ * size. Other than in blender::Set, a slot does not contain the key though. Instead it only
+ * contains an index into an array of keys that is stored separately.
*
* Some noteworthy information: